@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #if !defined (EXO_INSIDE_EXO_H) && !defined (EXO_COMPILATION)
@@ -30,7 +30,11 @@
 
 G_BEGIN_DECLS
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+void      exo_gtk_object_destroy_later                (GtkWidget      *object);
+#else
 void      exo_gtk_object_destroy_later                (GtkObject      *object);
+#endif
 
 void      exo_gtk_file_chooser_add_thumbnail_preview  (GtkFileChooser *chooser);
 
