@@ -93,12 +93,19 @@ exo_thumbnail_preview_init (ExoThumbnailPreview *thumbnail_preview)
   gtk_widget_set_sensitive (GTK_WIDGET (thumbnail_preview), FALSE);
 
   ebox = gtk_event_box_new ();
+#if !GTK_CHECK_VERSION (3, 0, 0)
+  /* TODO: Gtk3 */
   gtk_widget_modify_bg (ebox, GTK_STATE_NORMAL, &gtk_widget_get_style (ebox)->base[GTK_STATE_NORMAL]);
+#endif
   g_signal_connect (G_OBJECT (ebox), "style-set", G_CALLBACK (exo_thumbnail_preview_style_set), thumbnail_preview);
   gtk_container_add (GTK_CONTAINER (thumbnail_preview), ebox);
   gtk_widget_show (ebox);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new (FALSE, 0);
+#endif
   gtk_container_add (GTK_CONTAINER (ebox), vbox);
   gtk_widget_show (vbox);
 
@@ -111,16 +118,21 @@ exo_thumbnail_preview_init (ExoThumbnailPreview *thumbnail_preview)
   gtk_widget_show (button);
 
   label = gtk_label_new (_("Preview"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+  g_object_set (label, "xalign", 0.0f, "yalign", 0.5f, NULL);
   gtk_container_add (GTK_CONTAINER (button), label);
   gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
+#else
   box = gtk_vbox_new (FALSE, 2);
+#endif
+
   gtk_container_set_border_width (GTK_CONTAINER (box), 2);
   gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
   gtk_widget_show (box);
 
-  thumbnail_preview->image = gtk_image_new_from_stock (GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_DIALOG);
+  thumbnail_preview->image = gtk_image_new_from_icon_name ("image-missing", GTK_ICON_SIZE_DIALOG);
   gtk_widget_set_size_request (thumbnail_preview->image, EXO_THUMBNAIL_SIZE_NORMAL + 2 * 12, EXO_THUMBNAIL_SIZE_NORMAL + 2 * 12);
   gtk_image_set_pixel_size (GTK_IMAGE (thumbnail_preview->image), EXO_THUMBNAIL_SIZE_NORMAL / 2);
   gtk_box_pack_start (GTK_BOX (box), thumbnail_preview->image, FALSE, FALSE, 0);
@@ -148,11 +160,14 @@ exo_thumbnail_preview_style_set (GtkWidget           *ebox,
   _exo_return_if_fail (GTK_IS_EVENT_BOX (ebox));
 
   /* check if the ebox is already realized */
-  if (GTK_WIDGET_REALIZED (ebox))
+  if (gtk_widget_get_realized (ebox))
     {
       /* set background color (using the base color) */
       g_signal_handlers_block_by_func (G_OBJECT (ebox), exo_thumbnail_preview_style_set, thumbnail_preview);
-      gtk_widget_modify_bg (ebox, GTK_STATE_NORMAL, &ebox->style->base[GTK_STATE_NORMAL]);
+#if !GTK_CHECK_VERSION (3, 0, 0)
+      /*TODO: Gtk3 */
+      gtk_widget_modify_bg (ebox, GTK_STATE_NORMAL, &gtk_widget_get_style (ebox)->base[GTK_STATE_NORMAL]);
+#endif
       g_signal_handlers_unblock_by_func (G_OBJECT (ebox), exo_thumbnail_preview_style_set, thumbnail_preview);
     }
 }
@@ -267,7 +282,7 @@ _exo_thumbnail_preview_set_uri (ExoThumbnailPreview *thumbnail_preview,
     {
       /* the preview widget is insensitive if we don't have an URI */
       gtk_widget_set_sensitive (GTK_WIDGET (thumbnail_preview), FALSE);
-      gtk_image_set_from_stock (GTK_IMAGE (thumbnail_preview->image), GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_DIALOG);
+      gtk_image_set_from_icon_name (GTK_IMAGE (thumbnail_preview->image), "missing-image", GTK_ICON_SIZE_DIALOG);
       gtk_label_set_text (GTK_LABEL (thumbnail_preview->name_label), _("No file selected"));
     }
   else
@@ -363,7 +378,7 @@ _exo_thumbnail_preview_set_uri (ExoThumbnailPreview *thumbnail_preview,
           else
             {
               /* no thumbnail, cannot display anything useful then */
-              gtk_image_set_from_stock (GTK_IMAGE (thumbnail_preview->image), GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_DIALOG);
+              gtk_image_set_from_icon_name (GTK_IMAGE (thumbnail_preview->image), "missing-image", GTK_ICON_SIZE_DIALOG);
             }
         }
 
